@@ -41,7 +41,7 @@ access = match.arg(access, c('public','internal','cooperator','USGS'))
   }
   
   pkg.env$site = "http://waterservices.usgs.gov/nwis/site/"
-  pkg.env$iv = "http://nwis.waterservices.usgs.gov/nwis/iv/"
+  pkg.env$iv = "http://waterservices.usgs.gov/nwis/iv/"
   pkg.env$dv =  "http://waterservices.usgs.gov/nwis/dv/"
   pkg.env$gwlevels = "http://waterservices.usgs.gov/nwis/gwlevels/"
   pkg.env$measurements = "http://waterdata.usgs.gov/nwis/measurements/"
@@ -49,7 +49,7 @@ access = match.arg(access, c('public','internal','cooperator','USGS'))
   pkg.env$rating = "http://waterdata.usgs.gov/nwisweb/get_ratings/"
   pkg.env$qwdata = "http://nwis.waterdata.usgs.gov/nwis/qwdata"
   pkg.env$stat = "http://waterservices.usgs.gov/nwis/stat/"
-  
+
   options(Access.dataRetrieval = access)
 }
 
