@@ -12,15 +12,24 @@
 #' correctPCode <- zeroPad(pCode,5)
 #' pCodes <- c('100','1000','0','12345','1565465465465465')
 #' correctPCodes <- zeroPad(pCodes,5)
+#' pCodeNA <- c(1,2,NA)
+#' padPCodeNA <- zeroPad(pCodeNA,4)
 zeroPad <- function(x,padTo){
   if(padTo <= 1) return(x)
-  numDigits <- nchar(x)
+  
+  numDigits <- nchar(x, keepNA = TRUE)
   padding <- padTo-numDigits
-  padingZeros <- vapply(
+  
+  if(any(is.na(padding))){
+    padding[is.na(padding)] <- 0
+  }
+  
+  paddingZeros <- vapply(
       X = padding[padding > 0], 
-      FUN = function(y) paste(rep("0",y),collapse="",sep=""),
+      FUN = function(y) paste0(rep("0",y),collapse=""),
       FUN.VALUE = ""
   )
-  x[padding > 0] <- paste(padingZeros,x[padding > 0],sep="")
+  
+  x[padding > 0] <- paste0(paddingZeros,x[padding > 0])
   return(x)
 }
