@@ -66,7 +66,7 @@ test_that("CRAN-friendly importWaterML1 test", {
   fileName <- "WaterML1Example.xml"
   fullPath <- file.path(filePath, fileName)
   importUserWML1 <- importWaterML1(fullPath, asDateTime = TRUE)
-  
+  # saveRDS(importUserWML1, "rds/importUserWML1.rds")
   # default is to turn dates to characters
   expect_is(importUserWML1$dateTime, 'POSIXct')
   
@@ -83,6 +83,7 @@ test_that("External importWaterML1 test", {
   obs_url <- constructNWISURL(siteNumber,property,startDate,endDate,'dv')
 
   data <- importWaterML1(obs_url,TRUE)
+  # saveRDS(data, "rds/dvWML1.rds")
   expect_is(data$dateTime, 'POSIXct')
 
   groundWaterSite <- "431049071324301"
@@ -91,6 +92,7 @@ test_that("External importWaterML1 test", {
   groundwaterExampleURL <- constructNWISURL(groundWaterSite, NA,
            startGW,endGW, service="gwlevels")
   groundWater <- importWaterML1(groundwaterExampleURL)
+  # saveRDS(groundWater, "rds/groundwater.rds")
 
   expect_is(groundWater$dateTime, 'character')
 
@@ -99,11 +101,11 @@ test_that("External importWaterML1 test", {
   unitData <- importWaterML1(unitDataURL,TRUE)
   expect_is(unitData$dateTime, 'POSIXct')
 
-
   # Two sites, two pcodes, one site has two data descriptors
   siteNumber <- c('01480015',"04085427") #one site seems to have lost it's 2nd dd
   obs_url <- constructNWISURL(siteNumber,c("00060","00010"),startDate,endDate,'dv')
   data <- importWaterML1(obs_url)
+  # saveRDS(data, "rds/twoWML1.rds")
   expect_that(length(unique(data$site_no)) == 2, is_true())
   expect_that(ncol(data) == 8, is_true()) # 3 data, 3 remark codes, and 4 (agency, site, dateTime, tz)
 
@@ -115,28 +117,53 @@ test_that("External importWaterML1 test", {
   inactiveAndActive <- c("07334200","05212700")
   inactiveAndActive <- constructNWISURL(inactiveAndActive, "00060", "2014-01-01", "2014-01-10",'dv')
   inactiveAndActive <- importWaterML1(inactiveAndActive)
+  # saveRDS(inactiveAndActive, "rds/inactiveAndActive.rds")
   expect_that(length(unique(inactiveAndActive$site_no)) == 1, is_true())
-
+  
+  #raw XML
+  url <- constructNWISURL(service = 'dv', siteNumber = '02319300', parameterCd = "00060", 
+                          startDate = "2014-01-01", endDate = "2014-01-01")
+  raw <- content(GET(url), as = 'raw')
+  rawParsed <- importWaterML1(raw)
+  expect_true(nrow(rawParsed) > 0)
+  expect_true(data.class(rawParsed$X_00060_00003) == "numeric")
+ 
+  #no data
+  url <- constructNWISURL("05212700", "00060", "2014-01-01", "2014-01-10",'dv', statCd = "00001")
+  noData <- importWaterML1(url) 
+  expect_true(class(attr(noData,"url"))=="character")
+  expect_true(all(dim(noData)==0))
+  
+  url <- constructNWISURL(service = 'iv', site = c('02319300','02171500'), 
+                          startDate = "2015-04-04", endDate = "2015-04-05")
+  data <- importWaterML1(url, tz = "America/New_York", asDateTime = TRUE)
+  expect_true(data.class(data$dateTime) == "POSIXct")
+  expect_true(nrow(data) > 0)
 })
 
 context("importWaterML2")
+
 test_that("importWaterML2 internal test", {
   filePath <- system.file("extdata", package="dataRetrieval")
   fileName <- "WaterML2Example.xml"
   fullPath <- file.path(filePath, fileName)
   UserData <- importWaterML2(fullPath)
+  # saveRDS(UserData, "rds/UserData.rds")
   expect_is(UserData$value, 'numeric')
   expect_is(UserData$qualifier, 'character')
   
+})
+
 test_that("importWaterML2 external test", {
   testthat::skip_on_cran()
   url <- "http://waterservices.usgs.gov/nwis/iv/?format=waterml,2.0&sites=01646500&parameterCd=00060,00065"
   data <- importWaterML2(url)
+  # saveRDS(data, "rds/externalML2.rds")
   expect_is(data$value, 'numeric')
   expect_gt(nrow(data),0)
 })
   
-})
+
 
 context("importWQP_noCRAN")
 
@@ -155,3 +182,5 @@ test_that("External WQP tests", {
   STORETdata <- importWQP(STORETex)
   expect_is(STORETdata$ActivityStartDateTime, 'POSIXct')
 })
+
+
